<?php

namespace WpBeacon\Actions;

use stdClass;
use WP_Theme;
use WpBeacon\Data\PluginInfo;
use WpBeacon\Data\VersionInfo;

class GetThemeVersionsAction
{
    private static string $checkedAt;

    private static array $themes;

    public static function all(): array
    {
        $pluginInfos = [];

        $updates = get_site_transient('update_themes');

        self::$checkedAt = date(DATE_ATOM);
        self::$themes = wp_get_themes();

        if (empty($updates) || empty(self::$themes)) {
            return $pluginInfos;
        }

        return self::mapUpdateTransientOnPluginInfos($updates);
    }

    private static function mapUpdateTransientOnPluginInfos(stdClass $transient): array
    {
        return [
            ...self::mapPluginsOnPluginInfos($transient->response ?? []),
            ...self::mapPluginsOnPluginInfos($transient->no_update ?? []),
        ];
    }
    private static function mapPluginsOnPluginInfos(array $themes): array
    {
        if ($themes === []) {
            return $themes;
        }


        $pluginInfos = [];
        foreach ($themes as $key => $update) {
            $pluginInfos[] = self::mapUpdateThemesTransientItemOnPluginInfo($update, self::$themes[$key]);
        }

        return $pluginInfos;
    }

    private static function mapUpdateThemesTransientItemOnPluginInfo(array $update, WP_Theme $theme): PluginInfo
    {
        $pluginInfo = new PluginInfo(
            name: $theme->get('Name'),
            slug: $update['theme'],
            url: $theme->get('ThemeURI'),
            version: new VersionInfo(
                current: $theme->get('Version'),
                latest: $update['new_version'],
                checkedAt: self::$checkedAt,
                upToDate: $theme->update === false,
                releasedAt: null
            )
        );

        return $pluginInfo;
    }
}
