<?php

namespace WpBeacon\Providers;

use WpBeacon\Actions\GetCoreVersionsAction;
use WpBeacon\Actions\GetPluginVersionsAction;
use WpBeacon\Actions\GetThemeVersionsAction;
use Throwable;

class ApiServiceProvider implements Provider
{
    public function register(): void
    {
        add_action('rest_api_init', fn() => register_rest_route('beacon/v1', '/versions', [
            'methods' => 'GET',
            'callback' => fn() => self::getEndpointData(),
            'permission_callback' => fn() => current_user_can('manage_options'),
        ]));
    }

    private static function getEndpointData(): array
    {
        $data = [
            'wordpress' => [],
            'plugins' => [],
            'themes' => [],
        ];

        try {
            $data['wordpress'] = GetCoreVersionsAction::getCoreVersions();
            $data['plugins'] = GetPluginVersionsAction::all();
            $data['themes'] = GetThemeVersionsAction::all();
        } catch (Throwable $e) {
            error_log($e->getMessage());
        }

        return $data;
    }
}
